@@ -3,16 +3,11 @@ package Params::CheckCompiler::Compiler;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Eval::Closure;
 use List::SomeUtils qw( first_index );
-use Params::CheckCompiler::Exception::BadArguments;
-use Params::CheckCompiler::Exception::Named::Extra;
-use Params::CheckCompiler::Exception::Named::Required;
-use Params::CheckCompiler::Exception::Positional::Extra;
-use Params::CheckCompiler::Exception::Positional::Required;
-use Params::CheckCompiler::Exception::ValidationFailedForMooseTypeConstraint;
+use Params::CheckCompiler::Exceptions;
 use Scalar::Util qw( blessed looks_like_number reftype );
 use Sub::Name qw( subname );
 
@@ -588,7 +583,7 @@ Params::CheckCompiler::Compiler - Object that implements the check subroutine co
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =for Pod::Coverage .*
 
